<?php
/*
 * Theme Options
 * @package ftech
 * @since 1.0.0
 * */

if ( !defined( 'ABSPATH' ) ) {
    exit(); // exit if access directly
}

if ( class_exists( 'CSF' ) ) {

    //
    // Set a unique slug-like ID
    $prefix = 'ftech';

    //
    // Create options
    CSF::createOptions( $prefix . '_theme_options', array(
        'menu_title'         => 'ftech Option',
        'menu_slug'          => 'ftech-theme-option',
        'menu_type'          => 'menu',
        'enqueue_webfont'    => true,
        'show_in_customizer' => true,
        'menu_icon' => 'dashicons-category',
        'menu_position' => 50,
        'theme'                   => 'dark',
        'framework_title'    => wp_kses_post( 'Haptic Options <small>by Raziul <br/> Version: 1.0</small> ' ),
        'footer_text'    => wp_kses_post( 'The Theme will Created By Themexriver ' ),
    ) );

    // Create a top-tab
    CSF::createSection( $prefix . '_theme_options', array(
        'id'    => 'header_opts', // Set a unique slug-like ID
        'title' => 'Header',
    ) );


    /*-------------------------------------------------------
     ** Logo Settings  Options
    --------------------------------------------------------*/

    /*-------------------------------------------------------
     ** Header  Options
    --------------------------------------------------------*/

    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => 'General Settings',
        'id'     => 'general_settings',
        'icon'   => 'fa fa-refresh',
        'fields' => array(

            array(
                'id'      => 'preloader_enable',
                'title'   => esc_html__( 'Enable Preloader', 'ftech-tools' ),
                'type'    => 'switcher',
                'desc'    => esc_html__( 'Enable or Disable Preloader', 'ftech-tools' ),
                'default' => true,
            ),
            
            array(
                'id'      => 'ftech_logo_preloader',
                'title'   => esc_html__( 'Preloader Logo', 'ftech-tools' ),
                'type'    => 'media',
                'desc'    => esc_html__( 'Upload Your Brand Logo if you want', 'ftech-tools' ),
                'dependency' => array( 
                    'preloader_enable', '==', 'true',
                ),
            ),
            array(
                'id'      => 'ftech_custom_preloader',
                'title'   => esc_html__( 'Upload Loader Logo', 'ftech-tools' ),
                'type'    => 'media',
                'desc'    => esc_html__( 'If you Want to Upload Svg or png logo for preloader? them at first remove preloader logo text and then upload logo here', 'ftech-tools' ),
                'dependency' => array( 
                    'preloader_enable', '==', 'true',
                ),
            ),
            array(
                'id'      => 'scroll_up_btn',
                'title'   => esc_html__( 'Scroll Up SHOW/HIDE', 'ftech-tools' ),
                'type'    => 'switcher',
                'desc'    => esc_html__( 'Enable or Disable Scroll UP', 'ftech-tools' ),
                'default' => true,
            ),

        ),
    ) );

    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Header', 'ftech-tools' ),
        'parent'     => 'header_opts',
        'icon'   => 'fa fa-header',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Header Layout', 'ftech-tools' ) . '</h3>',
            ),

            array(
                'id'          => 'header_style',
                'type'        => 'select',
                'title'       => __('Select Header Style', 'ftech-tools' ),
                'options'     => Ftech_Plugin_Helper::get_header_types(),
            ), 
            array(
                'id'      => 'ftech_logo',
                'title'   => esc_html__( 'Default Logo', 'ftech-tools' ),
                'type'    => 'media',
                'desc'    => esc_html__( 'Upload Logo', 'ftech-tools' ),
                'default' => true,
            ),
           
        ),
    ) );

    
    /*-------------------------------------
     ** Typography Options
    -------------------------------------*/
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Typography', 'ftech-tools' ),
        'id'     => 'typography_options',
        'icon'   => 'fa fa-font',
        'fields' => array(

            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Body', 'ftech-tools' ) . '</h3>',
            ),

            array(
                'id'     => 'body-typography',
                'type'   => 'typography',
                'output' => 'body',

            ),

            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Heading', 'ftech-tools' ) . '</h3>',
            ),

            array(
                'id'     => 'heading-gl-typo',
                'type'   => 'typography',
                'output' => 'h1, h2, h3, h4, h5, h6',
            ),

        ),
    ) );

    // Product
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Woocommerce Option', 'ftech-tools' ),
        'id'     => 'woo_option',
        'icon'   => 'fa fa-header',
        'fields' => array(
            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Woocommerce Option', 'ftech-tools' ) . '</h3>',
            ),

            array(
                'id'      => 'product_count',
                'title'   => esc_html__( 'Product Count', 'ftech-tools' ),
                'type'    => 'text',
                'default' => '12',
            ),
            array(
				'id'       => 'enable_shop_preadcrumb',
				'type'     => 'switcher',
				'title'    => __( 'Page Breadcrumb', 'ftech-plugin' ),
				'text_on'  => __( 'Yes', 'ftech-plugin' ),
				'text_off' => __( 'No', 'ftech-plugin' ),
				'default'  => true
			),
            array(
                'id'      => 'shop_breadcrumb_bg',
                'title'   => esc_html__( 'Shop Breadcrumb BG', 'ftech-tools' ),
                'type'    => 'media',
                'dependency' => array( 'enable_shop_preadcrumb', '==', 'true' ),
            ),
            array(
                'id'      => 'shop_breadcrumb_title',
                'title'   => esc_html__( 'Shop Breadcrumb Title', 'ftech-tools' ),
                'type'    => 'text',
                'dependency' => array( 'enable_shop_preadcrumb', '==', 'true' ),
            ),
            array(
				'id'       => 'enable_single_product_preadcrumb',
				'type'     => 'switcher',
				'title'    => __( 'Shop Enable Breadcrumb', 'ftech-plugin' ),
				'text_on'  => __( 'Yes', 'ftech-plugin' ),
				'text_off' => __( 'No', 'ftech-plugin' ),
				'default'  => true
			),
            array(
                'id'      => 'product_single_breadcrumb_bg',
                'title'   => esc_html__( 'Product Single Breadcrumb BG', 'ftech-tools' ),
                'type'    => 'media',
                'dependency' => array( 'enable_single_product_preadcrumb', '==', 'true' ),
            ),
            array(
                'id'      => 'product_single_breadcrumb_title',
                'title'   => esc_html__( 'Shop Breadcrumb Title', 'ftech-tools' ),
                'type'    => 'text',
                'dependency' => array( 'enable_single_product_preadcrumb', '==', 'true' ),
            ),
           
        ),
    ) );

    // blog optoins
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Breadcrumb', 'ftech-tools' ),
        'id'     => 'blog_page',
        'icon'   => 'fa fa-rss-square',
        'fields' => array(
            array(
                'id'      => 'breadcrumb_bg_img',
                'type'    => 'media',
                'title'   => esc_html__('Breadcrumb BG', 'ftech-tools'),
            ),
        ),
    ) );

    // blog optoins
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Blog', 'ftech-tools' ),
        'id'     => 'blog_page',
        'icon'   => 'fa fa-rss-square',
        'fields' => array(

            array(
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( 'Blog Options', 'ftech-tools' ) . '</h3>',
            ),
            
            array(
                'id'      => 'br_custom_title',
                'type'    => 'text',
                'title'   => esc_html__('Blog Breadcrumb Title', 'ftech-tools'),
                'desc'    => esc_html__('If you Do not Blog Breadcrumb Custom Title then type Title Here', 'ftech-tools'),
            ),
            array(
                'id'      => 'breadcrumb_bg',
                'type'    => 'media',
                'title'   => esc_html__('Breadcrumb BG', 'ftech-tools'),
            ),
            
            array(
                'id'      => 'blog_btn_text',
                'type'    => 'text',
                'title'   => esc_html__( 'Blog Read More Button', 'ftech-tools' ),
                'default' => esc_html__( 'Explore More', 'ftech-tools' ),
                'desc'    => esc_html__( 'Type Blog Read More Button Text Here', 'ftech-tools' ),
            ),
        ),
    ) );
    

   // ftech Color Setting
   CSF::createSection( $prefix . '_theme_options', array(
    'title'  => 'Color Control',
    'id'     => 'apix_color_control',
    'icon'   => 'fa fa-paint-brush',
    'fields' => array(
        

        array(  //nav bar one start
            'type'    => 'subheading',
            'content' => '<h3>' . esc_html__( 'Theme Global Color', 'ftech-tools' ) . '</h3>',
        ),
        array(
            'id'    => 'theme-color-1',
            'type'  => 'color',
            'title' => 'Theme Primary Color',
            'default' => '#c4ef17'
        ),
        array(
            'id'    => 'theme-color-2',
            'type'  => 'color',
            'title' => 'Theme Heading Color',
            'default' => '#222627'
        ),
        
        
    ),
) );

    // Create a section
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => 'Error Page',
        'id'     => 'error_page',
        'icon'   => 'fa fa-exclamation-triangle',
        'fields' => array(
            

            array(  //nav bar one start
                'type'    => 'subheading',
                'content' => '<h3>' . esc_html__( '404 Page Options', 'ftech-tools' ) . '</h3>',
            ),
            
            array(
                'id'      => 'error_code',
                'type'    => 'media',
                'title'   => esc_html__( 'Error Code Image', 'ftech-tools' ),
            ),
            array(
                'id'      => 'error_title',
                'type'    => 'text',
                'title'   => esc_html__( '404 Title', 'ftech-tools' ),
                'default' => esc_html__( 'Oops! Page Not found.', 'ftech-tools' ),
            ),
           
            array(
                'id'      => 'error_button',
                'type'    => 'text',
                'title'   => esc_html__( '404 Button', 'ftech-tools' ),
                'default' => esc_html__( 'back to Home page ', 'ftech-tools' ),
            )

                     
        ),
    ) );

    /*-------------------------------------------------------
     ** Footer  Options
    --------------------------------------------------------*/
    
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Footer Options', 'ftech-tools' ),
        'icon'   => 'fa fa-copyright',
        'fields' => array(

            array(
                'id'          => 'footer_style',
                'type'        => 'select',
                'title'       => __('Select Footer Style', 'ftech-tools' ),
                'options'     => Ftech_Plugin_Helper::get_footer_types(),
            ),     
            array(
                'id'    => 'footer_copyright',
                'type'  => 'wp_editor',
                'title' => 'Default Footer Copyright',
                'default' => '© 2023 ftech - IT Services. All rights reserved.',
            ),

        ),
    ) );

    // Backup section
    CSF::createSection( $prefix . '_theme_options', array(
        'title'  => esc_html__( 'Backup Export', 'ftech-tools' ),
        'id'     => 'backup_options',
        'icon'   => 'fa fa-window-restore',
        'fields' => array(
            array(
                'type' => 'backup',
            ),
        ),
    ) );




}